use "model_dataset.dta", clear

//Preparing the variables
gen ln_gdp=ln(gdp_percapita)
gen N=TFR/2
sort country year
bysort country: gen lagN = N[_n-25]

gen unwanted_fertility=TFR-wanted_fertility
gen q=1-(under5_mort/1000)
gen surviving_births=q*TFR

gen taug=govt_exp_edu/100
gen h=exp_yrs_sch

//To get mapping between h and h
reg h yr_sch_h if early_oecd==0 [aweight=working_age_population]

//Data moments for calibration
gen gdp_perworker=GDP/working_age_population
gen hh_cons_perworker=hh_cons/working_age_population

gen initial_sam60=1 if TFR!=. & yr_sch!=. & gdp_perworker!=. & year==1960
bysort country: egen initial60=mean(initial_sam60)

gen initial_sam60new=1 if TFR!=. & exp_yrs_sch!=. & gdp_perworker!=. & year==1980
bysort country: egen initial60new=mean(initial_sam60new)

//Inputs for calibration and outputs for comparison
sum TFR q surviving_births gdp_perworker hh_cons_perworker working_age_population if year==1960 & initial60new==1 & early_oecd==0 [aweight=working_age_population]

sum TFR q surviving_births gdp_perworker working_age_population if year==1985 & initial60new==1 & early_oecd==0 [aweight=working_age_population]

sum TFR q surviving_births if year==2010 & initial60new==1 & early_oecd==0 [aweight=working_age_population]

//exp_yrs_sch is the expected years of schooling at 5 years of age so use from 5 years earlier to get expected years at birth
sum exp_yrs_sch if year==1980 & initial60new==1 & early_oecd==0 [aweight=working_age_population]

sum exp_yrs_sch if year==2005 & initial60new==1 & early_oecd==0 [aweight=working_age_population]

sum taug if year==2010 & initial60new==1 & early_oecd==0 [aweight=GDP]

sum unwanted_fert if initial60new==1 & early_oecd==0 & year>=2008 & year<=2012 [aweight=population]
sum unwanted_fert if initial60new==1 & early_oecd==0 & year>=1985 & year<=1995 [aweight=population]


//Preparing for Figure 2
//population weighted average TFR for developing countries for which GDP data is available in 1960
gen sample60=1 if TFR!=. & ln_gdp!=. & year==1960 & early_oecd!=.
bysort country: egen sample1960=mean(sample60)

gen dev_TFR_series=.
quietly forvalues i=1960/2015 {
		sum TFR [aweight=population] if year==`i' & early_oecd==0 & sample1960==1
		replace dev_TFR_series=r(mean) if year==`i' & early_oecd==0 & sample1960==1
}

gen dev_gdp_series=.
quietly forvalues i=1960/2015 {
		sum ln_gdp [aweight=population] if year==`i' & early_oecd==0 & sample1960==1
		replace dev_gdp_series=r(mean) if year==`i' & early_oecd==0 & sample1960==1
}



//Figure 2
twoway (scatter TFR ln_gdp if year==1960, xaxis(1) mcolor(black) msize(small) msymbol(plus))  ///
	(lowess TFR ln_gdp if year==1960, lwidth(0.5) c(l) xaxis(1) lcolor(black)) ///
	(scatter TFR ln_gdp if year==2014, xaxis(1) mcolor(black) msize(small) msymbol(triangle)) ///
	(lowess TFR ln_gdp if year==2014, c(l) xaxis(1) lwidth(0.5) lcolor(black) lpattern(dash_dot)) ///
	(line dev_TFR_series dev_gdp_series if country=="India", sort c(l)  ytitle(TFR) ///
	xscale(range(5(1) 10)) xlabel(5(1)10) lwidth(0.5) lcolor(gs10) lpattern(dash)) if sample1960==1, ///
	legend(order(1 "1960 cross section" 2 "Lowess TFR-Income 1960" 3 "2014 Cross section" ///
	4 "Lowess TFR-Income 2014" 5 "TFR-Income: dev countries over time") size(small) span)


//1. Re-estimating phi 
//Averaging out government spending on FPPs
egen cntry=group(country) 
gen avg_funds_pc_overall=.
quietly forvalues i = 1/264 { 
	summarize FPP_all_pc_real [aweight=population] if cntry == `i'
	replace avg_funds_pc_overall = r(mean) if cntry == `i' 
 } 

gen ln_avg_pc_overall=ln(avg_funds_pc_overall)
gen P11a_all=ln_avg_pc_overall

sum P11a_all if year==2010 & early_oecd==0 [aweight=working_age_population]

//Preparing the regression variables
gen indvar1=N-lagN
gen indvar2=lagN-1
gen indvar311a_all=(lagN-1)*P11a_all

//using govt spending and adjusting exp. years schooling and tauH
gen depvar21_new1=0.1987/N-((0.0254+0.006*h)/(1-(0.0254+0.006*h)*N))-0.2*(N-lagN) //psi held constant at 0.1

//Estimation of equation 15
reg depvar21_new1 indvar311a_all if year==2010 & early_oecd==0, noconstant robust //uses expected yrs schooling

//2. Re-estimating phi for mortality extension
sort country year
bysort country: gen lagq = q[_n-25]

gen indvar2_mort=q*(lagN*lagq-1)
gen indvar3_mort=indvar2_mort*P11a_all

gen tau_term_new1=(0.0372+0.0069*h)/(1-(0.0372+0.0069*h)*N*q)
gen depvar2_mort_new1=((0.192*(1+((1-q)/(2*N*q))))/N)-(tau_term_new1)*q*(1+(tau_term_new1*(1-q)/2)*(tau_term_new1*N*q+(1/(1-(0.0372+0.0069*h)*N*q))))-0.1*q*(1-q)-0.2*q*(N*q-lagN*lagq)

//Estimation of equation 19
reg depvar2_mort_new1 indvar3_mort if year==2010 & early_oecd==0, noconstant robust //with gov spending


//3. Other values of psi
gen depvar11_new1=0.1987/N-((0.0254+0.006*h)/(1-(0.0254+0.006*h)*N)) 

gen depvar21_tinypsi_new2=depvar11_new1-0.02*(N-lagN) //psi=0.01
gen depvar21_smallpsi_new2=depvar11_new1-0.1*(N-lagN) //psi=0.05
gen depvar21_bigpsi_new2=depvar11_new1-(N-lagN) //psi=0.5
gen depvar21_hugepsi_new2=depvar11_new1-1.8*(N-lagN) //psi=0.9


//Estimating changes to phi for different values of psi
reg depvar21_tinypsi_new2 indvar311a_all if year==2010 & early_oecd==0, noconstant robust
reg depvar21_smallpsi_new2 indvar311a_all if year==2010 & early_oecd==0, noconstant robust
reg depvar21_bigpsi_new2 indvar311a_all if year==2010 & early_oecd==0, noconstant robust
reg depvar21_hugepsi_new2 indvar311a_all if year==2010 & early_oecd==0, noconstant robust

	
//4. Country-Specific Simulations
gen specific_sample=1 if country=="El Salvador" | country=="Malaysia" | country=="Singapore" | country=="India" | ///
	country=="Philippines" | country=="Tunisia" | country=="Pakistan" | country=="Botswana" | country=="Turkey" | ///
	country=="Korea, Rep." | country=="Thailand" | country=="Indonesia" | country=="Mauritania" | country=="Zimbabwe" | ///
	country=="Benin"
label var specific_sample "Sample for country-specific simulations"

egen cntry_specific=group(country) if specific_sample==1

//Inputs for calibration and outputs for comparison
forvalues i=1/15 {
sum TFR yr_sch_h gdp_perworker hh_cons_perworker working_age_population if year==1960 & cntry_specific==`i'
sum TFR gdp_perworker working_age_population if year==1985 & cntry_specific==`i'
sum TFR if year==2010 & cntry_specific==`i'

sum exp_yrs_sch if year==1980 & cntry_specific==`i'
sum exp_yrs_sch if year==2005 & cntry_specific==`i'

sum taug P11a_all if year==2010 & cntry_specific==`i'
}


//Find missing data from closest year
sum hh_cons_perworker if year==1975 & country=="Botswana"
sum gdp_perworker if year==1975 & country=="Botswana"

sum hh_cons_perworker if year==1965 & country=="El Salvador"
sum gdp_perworker if year==1965 & country=="El Salvador"

sum hh_cons_perworker if year==1965 & country=="Tunisia"
sum gdp_perworker if year==1965 & country=="Tunisia"

sum hh_cons_perworker if year==1986 & country=="Pakistan"
sum gdp_perworker if year==1986 & country=="Pakistan"

sum hh_cons_perworker if year==1987 & country=="Turkey"
sum gdp_perworker if year==1987 & country=="Turkey"

sum hh_cons_perworker if year==2005 & country=="Zimbabwe"
sum gdp_perworker if year==2005 & country=="Zimbabwe"

sum hh_cons_perworker if year==1975 & country=="Singapore"
sum gdp_perworker if year==1975 & country=="Singapore"

tab year if taug!=. & country=="Botswana"
tab taug if country=="Botswana" & year==2009
tab year if taug!=. & country=="Korea, Rep."
tab taug if country=="Korea, Rep." & year==2009
tab year if taug!=. & country=="Philippines"
tab taug if country=="Philippines" & year==2009
tab year if taug!=. & country=="Turkey"
tab taug if country=="Turkey" & year==2012

//Data moments used for calibration are stored in the file "params.mat"

//5. Out-of-sample fit exercise
//Input for calibration 
use "maddison.dta", clear
sum rgdpnapc if year==1850 & advanced_economies==1 [aweight=pop]
sum rgdpnapc if year==1875 & advanced_economies==1 [aweight=pop]

use "hist_edu.dta", clear
sum tyr if region_code==1 & year==1870 [ aweight=pop]

//Results of out-of-sample exercise
use "advanced_economies.dta", clear
gen avg_TFR=.
forvalues i=1/16 {
	sum TFR [aweight=POP] if t==`i'
	replace avg_TFR=r(mean) if t==`i'
}

//feed the model predictions in from MATLAB simulations
gen model=4.8 if year==1850
replace model=4.523 if year==1875
replace model=4.0999 if year==1900
replace model=3.538 if year==1925
replace model=2.823 if year==1950

//Figure 5
twoway (line model year if Country=="Australia" & year<1955 & year>1845, lpattern(dash) lwidth(thick) lcolor(black)) ///
	(line avg_TFR year if Country=="Australia" & year>1845, lwidth(thick) lcolor(black)) ///
	(scatter TFR year if year>1845, msize(small) msymbol(circle_hollow) mcolor(grey)), ///
	legend(order(1 "Model predictions" 2 "Advanced economies' average" 3 "Advanced economies' TFR") ///
	size(small) span) xscale(range(1850(25) 1950))

*****APPENDICES*****
//1. Regression of wanted and unwanted fertility on spending on FPPs
sort country year

//create continuous dataset for years of schooling
gen yr_sch_full=yr_sch
replace yr_sch_full=yr_sch[_n+1] if yr_sch_full==.
replace yr_sch_full=yr_sch[_n-1] if yr_sch_full==.
replace yr_sch_full=yr_sch[_n+2] if yr_sch_full==.
replace yr_sch_full=yr_sch[_n-2] if yr_sch_full==.
replace yr_sch_full=yr_sch[_n+3] if yr_sch_full==.
replace yr_sch_full=yr_sch[_n-3] if yr_sch_full==.

//generate latest year for which unwanted fertility is available
bysort country: egen latest_year=max(year) if unwanted_fert!=.
bysort country: egen latest_year_unwanted=mean(latest_year)

//Regression
reg wanted_fert ln_avg_pc_overall ln_gdp IMR urban_pop_tot yr_sch_full if latest_year_unwanted==year, robust
eststo wanted
reg unwanted_fert ln_avg_pc_overall ln_gdp IMR urban_pop_tot yr_sch_full if latest_year_unwanted==year, robust
eststo unwanted

esttab wanted unwanted, se star


//2. Regression of private education spending on public education spending	
use "OECD_edu_data.dta", clear
gen ln_gdp=ln(GDPpercapita)
gen total_pub=Publicexpenditureoneducation+ Publiceducationexpenditurete
gen total_priv=Privateexpenditureoneducation +Privateeducationexpendituret

egen cntry=group(LOCATION)
xtset cntry TIME
xtreg total_priv total_pub ln_gdp i.TIME, fe
